@@ -1,5 +1,5 @@
 from django.db import models
-from wagtail.core.fields import StreamField
+from wagtail.fields import StreamField
 
 from .blocks import FormStreamBlock
 from .views import form_page_view
@@ -28,7 +28,7 @@ class ProccessFormMixin(object):
 
 
 class FormBuilderPageMixin(ProccessFormMixin, models.Model):
-    form = StreamField(FormStreamBlock())
+    form = StreamField(FormStreamBlock(), use_json_field=True)
     email_subject = models.CharField(max_length=255, help_text='Subject for the automated email')
     email_to = models.EmailField(help_text='Address automated emails are sent to')
 
