@@ -14,11 +14,9 @@ from django.template.loader import render_to_string
 from django.urls import reverse
 from django.utils.html import format_html, format_html_join
 from django.utils.safestring import SafeText, mark_safe
-from wagtail.core.models import Page, Site
-from wagtail.images import get_image_model
-from webpack_loader.templatetags.webpack_loader import render_bundle
-
-Image = get_image_model()
+from markupsafe import Markup
+from wagtail.models import Page, Site
+from webpack_loader.templatetags.webpack_loader import render_bundle as base_render_bundle
 
 
 def add_form_class(bound_field, new_classes):
@@ -47,6 +45,11 @@ def include_static(path):
         return f.read()
 
 
+@jinja2.pass_context
+def render_bundle(context, *args, **kwargs):
+    return base_render_bundle(context, *args, **kwargs)
+
+
 def debug_variable(variable):
     """Print all the fields available on a variable"""
     return format_html('<pre>{}</pre>', dir(variable))
@@ -57,7 +60,7 @@ def url(name, *args, **kwargs):
     return reverse(name, args=args or None, kwargs=kwargs or None)
 
 
-@jinja2.contextfunction
+@jinja2.pass_context
 def site_root(context):
     """Get the root page for the site"""
     # This lookup will be cached on the intermediary objects, so this will only
@@ -74,7 +77,7 @@ def svg_inline(name):
     return mark_safe(render_to_string('svgs/%s.svg' % name))
 
 
-@jinja2.contextfunction
+@jinja2.pass_context
 def breadcrumbs(context, page=None):
     """Print the top navigation menu for this site"""
     request = context.get('request')
@@ -83,7 +86,7 @@ def breadcrumbs(context, page=None):
         page = context.get('page')
     ancestors = page.get_ancestors().filter(depth__gte=root.depth)
 
-    return jinja2.Markup(render_to_string('tags/breadcrumbs.html', {
+    return Markup(render_to_string('tags/breadcrumbs.html', {
         'page': page,
         'ancestors': ancestors,
         'request': request,
@@ -108,7 +111,7 @@ def model_classname(model_or_instance):
         return ''
 
 
-@jinja2.contextfunction
+@jinja2.pass_context
 def messages(context):
     """Get any messages from django.contrib.messages framework"""
     return get_messages(context.get('request'))
@@ -118,10 +121,10 @@ def json_dumps(value):
     """
     Dump the value to a JSON string. Useful when sending values to JavaScript
     """
-    return jinja2.Markup(json.dumps(value, cls=DjangoJSONEncoder))
+    return Markup(json.dumps(value, cls=DjangoJSONEncoder))
 
 
-@jinja2.contextfunction
+@jinja2.pass_context
 def qs(context, get=None, **kwargs):
     """
     Update a querydict with new values, and return it as a URL encoded string.
@@ -167,13 +170,13 @@ def source_tag(image, media, normal_spec, retina_spec):
 
 
 def render_honeypot_field():
-    return jinja2.Markup(render_to_string('honeypot/honeypot_field.html', {
+    return Markup(render_to_string('honeypot/honeypot_field.html', {
         'fieldname': settings.HONEYPOT_FIELD_NAME,
         'value': ''
     }))
 
 
-@jinja2.contextfunction
+@jinja2.pass_context
 def analytics_js(context):
     hide: bool = settings.DEBUG
     if request := context.get('request'):
@@ -184,7 +187,7 @@ def analytics_js(context):
     return ''
 
 
-def _gen_sources(image: Image, sizes: List[Tuple[int, str]],
+def _gen_sources(image, sizes: List[Tuple[int, str]],
                  aspect_ratio: float) -> Union[SafeText, None]:
     def html_attrs():
         for pixel_width, media_attr in sizes:
@@ -206,7 +209,7 @@ def _size_refactor(size_tuple: Tuple[int, str], factor: float) -> Tuple[int, str
     return (int(size_tuple[0] * factor), size_tuple[1])
 
 
-def aspect_picture_mobile(image: Image, dimensions: Tuple[int, int]) -> SafeText:
+def aspect_picture_mobile(image, dimensions: Tuple[int, int]) -> SafeText:
     # height / width
     aspect_ratio = dimensions[1] / dimensions[0]
     # Calculate the percentage the image takes up of the 'default width'
@@ -219,7 +222,7 @@ def aspect_picture_mobile(image: Image, dimensions: Tuple[int, int]) -> SafeText
     return _gen_sources(image, sizes, aspect_ratio) or SafeText('')
 
 
-def aspect_picture_desktop(image: Image, dimensions: Tuple[int, int]) -> SafeText:
+def aspect_picture_desktop(image, dimensions: Tuple[int, int]) -> SafeText:
     # height / width
     aspect_ratio = dimensions[1] / dimensions[0]
     # Calculate the percentage the image takes up of the 'default width'
@@ -234,9 +237,9 @@ def aspect_picture_desktop(image: Image, dimensions: Tuple[int, int]) -> SafeTex
     return _gen_sources(image, sizes, aspect_ratio) or SafeText('')
 
 
-def aspect_picture(image: Image, desktop_dimensions: Tuple[int, int],
+def aspect_picture(image, desktop_dimensions: Tuple[int, int],
                    mobile_dimensions: Tuple[int, int], html_class: str = '') -> SafeText:
-    if not Image:
+    if not image:
         return SafeText('')
 
     sources_markup = aspect_picture_mobile(image, mobile_dimensions) + \
@@ -251,7 +254,7 @@ def aspect_picture(image: Image, desktop_dimensions: Tuple[int, int],
             {0}
             {1}
         </picture>
-    """, sources_markup, default_image.img_tag(), html_class)
+    """, sources_markup, default_image.img_tag(), mark_safe(html_class))
 
 
 class Extension(jinja2.ext.Extension):
