@@ -7,7 +7,7 @@ from django.core.serializers.json import DjangoJSONEncoder
 from django.utils.text import slugify
 from django.utils.timezone import now
 from wagtail import __version__ as wt_version
-from wagtail.core.models import Page, Site
+from wagtail.models import Page, Site
 
 from coop.models import AnalyticsSettings
 
