@@ -1,9 +1,9 @@
 from django.db import models
-from wagtail.contrib.settings.models import BaseSetting, register_setting
+from wagtail.contrib.settings.models import BaseSiteSetting, register_setting
 
 
 @register_setting(icon='site')
-class AnalyticsSettings(BaseSetting):
+class AnalyticsSettings(BaseSiteSetting):
     google_analytics = models.CharField(
         max_length=255, blank=True, null=True,
         help_text='Your Google Analytics property ID, e.g UA-XXXXX-Y')
