@@ -4,9 +4,8 @@ from django.conf import settings
 from django.core.mail import EmailMessage
 from django.db import models
 from django.template.response import TemplateResponse
-from wagtail.admin.edit_handlers import FieldPanel, MultiFieldPanel
-from wagtail.core import models as wagtailmodels
-from wagtail.images.edit_handlers import ImageChooserPanel
+from wagtail import models as wagtailmodels
+from wagtail.admin.panels import FieldPanel, MultiFieldPanel
 from wagtailmetadata.models import MetadataPageMixin
 
 from .forms import ContactForm
@@ -28,7 +27,7 @@ class Page(MetadataPageMixin, wagtailmodels.Page):
             FieldPanel('slug'),
             FieldPanel('seo_title'),
             FieldPanel('search_description'),
-            ImageChooserPanel('search_image'),  # From MetadataPageMixin
+            FieldPanel('search_image'),  # From MetadataPageMixin
         ], 'Common page configuration'),
     ]
 
