@@ -25,7 +25,6 @@ INSTALLED_APPS = [
     'taggit',
     'modelcluster',
     'wagtailmetadata',
-    'wagtailaccessibility',
     'wagtailcache',
     'wagtailfontawesome',
     'webpack_loader',
@@ -41,7 +40,7 @@ INSTALLED_APPS = [
     'django.contrib.sitemaps.views',
 
     # Wagtail apps
-    'wagtail.core',
+    'wagtail',
     'wagtail.admin',
     'wagtail.documents',
     'wagtail.snippets',
@@ -129,12 +128,11 @@ TEMPLATES_JINJA = {
     'APP_DIRS': True,
     'OPTIONS': {
         'extensions': [
-            'wagtail.core.jinja2tags.core',
+            'wagtail.jinja2tags.core',
             'wagtail.admin.jinja2tags.userbar',
             'wagtail.images.jinja2tags.images',
             'wagtail.contrib.settings.jinja2tags.settings',
             'coop.jinja2tags.core.Extension',
-            'wagtailaccessibility.jinja2tags.tota11y',
             'wagtailmetadata.jinja2tags.WagtailMetadataExtension',
         ],
     },
@@ -186,3 +184,5 @@ WAGTAILEMBEDS_RESPONSIVE_HTML = True
 
 # Override if you actually need a zip_code
 HONEYPOT_FIELD_NAME = 'zip_code'
+
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
