@@ -1,4 +1,4 @@
-from wagtail.core.blocks.stream_block import StreamValue
+from wagtail.blocks.stream_block import StreamValue
 
 
 def streamfield_mapper(model_name, field_name, mapper):
