@@ -6,7 +6,7 @@ import random
 from pathlib import Path
 
 from django.conf import settings
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.core.files.storage import default_storage
 from django.core.serializers.json import DjangoJSONEncoder
 from django.utils import lorem_ipsum
@@ -85,12 +85,12 @@ def hr():
 
 
 def r_anchor(num):
-    return("<a href='http://example.com'>{0}</a>".format(lwords(num)))
+    return ("<a href='http://example.com'>{0}</a>".format(lwords(num)))
 
 
 def r_image():
     image = get_random_image()
-    return('<embed alt="Example image" embedtype="image" format="fullwidth" id="{0}"/>'.format(image.id))
+    return ('<embed alt="Example image" embedtype="image" format="fullwidth" id="{0}"/>'.format(image.id))
 
 
 def embed_video():
@@ -228,7 +228,11 @@ def get_random_video_url():
 
 
 def make_superuser():
-    User.objects.create_superuser(username='admin', email='', password='p')
+    User = get_user_model()
+    if User.USERNAME_FIELD == 'email':
+        User.objects.create_superuser(email='admin@admin.com', password='p')
+    else:
+        User.objects.create_superuser(username='admin', email='admin@admin.com', password='p')
 
 
 def generate_form_streamfield(headings=True, file_field=True):
