@@ -1,14 +1,15 @@
 from django.conf import settings
 from django.template.loader import render_to_string
 from django.utils.html import mark_safe
-from wagtail.core import hooks
-from wagtail.core.models import Site
+from wagtail import hooks
+from wagtail.admin.ui.components import Component
+from wagtail.models import Site
 from wagtailcache.cache import clear_cache
 
 from .models import AnalyticsSettings
 
 
-class AnalyticsWarningPanel(object):
+class AnalyticsWarningPanel(Component):
     name = 'analytics_warning_panel'
     order = 200
 
@@ -17,8 +18,9 @@ class AnalyticsWarningPanel(object):
         if not site:
             raise ValueError("Need an active site to show analytics warnings")
         self.site = site
+        super().__init__()
 
-    def render(self):
+    def render_html(self, parent_context=None) -> str:
         instance = AnalyticsSettings.for_site(self.site)
         if not instance.google_analytics and not instance.google_tag_manager:
             return mark_safe(render_to_string('coop/analytics_warning.html', {
